@@ -130,6 +130,8 @@ class PythonInstaller(object):
         elif is_python26(version):
             if version < '2.6.6':
                 patch_dir = os.path.join(PATH_PATCHES_ALL, "python26")
+                if version < '2.6.3':
+                    self._add_patches_to_list(patch_dir, ['patch-Makefile.pre.in-for-2.6.2-and-earlier.diff'])
                 self._add_patches_to_list(patch_dir, ['patch-setup.py-for-2.6.5-and-earlier.diff'])
                 self._add_patches_to_list(patch_dir, ['patch-_ssl.c-for-ubuntu-oneiric-and-later.diff'])
             else:
@@ -142,6 +144,9 @@ class PythonInstaller(object):
             if version == '2.7.3':
                 patch_dir = os.path.join(PATH_PATCHES_ALL, "python27")
                 self._add_patches_to_list(patch_dir, ['patch-Modules-_sqlite-connection.c.diff'])
+            if version == '2.7.4':
+                patch_dir = os.path.join(PATH_PATCHES_ALL, "python27")
+                self._add_patches_to_list(patch_dir, ['patch-Modules-_sqlite-for-2.7.4.diff'])
         elif is_python30(version):
             patch_dir = os.path.join(PATH_PATCHES_ALL, "python30")
             self._add_patches_to_list(patch_dir, ['patch-setup.py.diff'])
